@@ -1,3 +1,4 @@
+import logging
 import os
 
 from vectorcode import __version__
@@ -7,11 +8,14 @@ from vectorcode.cli_utils import (
     find_project_config_dir,
     load_config_file,
 )
-from vectorcode.subcommands import drop, init, ls, query, vectorise
+from vectorcode.subcommands import check, drop, init, ls, query, vectorise
 
 
 def main():
     cli_args = cli_arg_parser()
+    if cli_args.action == CliAction.check:
+        # NOTE: `check` is designed to be faster than the other actions.
+        return check(cli_args)
     project_config_dir = find_project_config_dir(cli_args.project_root)
 
     if project_config_dir is not None:
@@ -23,6 +27,11 @@ def main():
     else:
         final_configs = load_config_file().merge_from(cli_args)
 
+    if final_configs.pipe:
+        # NOTE: NNCF (intel GPU acceleration for sentence transformer) keeps showing logs.
+        # This disables logs below ERROR so that it doesn't hurt the `pipe` output.
+        logging.disable(logging.ERROR)
+
     return_val = 0
     match final_configs.action:
         case CliAction.query:
